@@ -4,7 +4,7 @@ use 5.6.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.074';
+our $VERSION = '0.075';
 
 
 # Preloaded methods go here.
@@ -135,7 +135,10 @@ C<skepsis> or at least create this database and tables.
 
   RewriteEngine on
 
-  RewriteRule ^/user/(.*[^\.xsp].*) /user/user.xsp?username=$1 
+  Alias /user/submit/ /var/www/user/submit/user.xsp 
+  RewriteRule /user/submit/new(.*) /var/www/user/submit/new.xsp$1 
+
+  RewriteRule ^/user/([^submit/].*) /user/submit/user.xsp?username=$1 
 
   Alias /news/submit /var/www/news/submit.xsp 
 
